@@ -1,9 +1,9 @@
 /* Test of vasnprintf() and asnprintf() functions.
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2023 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -113,7 +113,7 @@ test_asnprintf ()
 }
 
 int
-main (int argc, char *argv[])
+main ()
 {
   test_vasnprintf ();
   test_asnprintf ();
